@@ -1,10 +1,15 @@
-from mcp.server.fastmcp import FastMCP
+from mcp.server import Server
 
 # Create an MCP server
-mcp = FastMCP("geocount")
+mcp = Server("geocount")
 
 
 # Add an addition tool
+@mcp.list_tools()
+def list_tools() -> list:
+    """List all available tools"""
+    return ["add", "subtract"]
+
 @mcp.tool()
 def add(a: int, b: int) -> int:
     """Add two numbers"""
@@ -22,6 +27,8 @@ def get_greeting(name: str) -> str:
     """Get a personalized greeting"""
     return f"Hello, {name}!"
 
+options = mcp.create_initialization_options()
+
 if __name__ == "__main__":
-    mcp.run()
+    mcp.run(read_stream=True, write_stream=True, options=options)
  
\ No newline at end of file
